import { Options } from 'serverless';
interface ApiGatewayIntegration {
    type: 'sqs';
    name: string;
    visibilityTimeout?: number;
    path?: string;
    authorizationType?: string;
    authorizerId?: string;
}
interface AwsProvider {
    getStage: () => string;
    getRegion: () => string;
    naming: {
        generateApiGatewayDeploymentLogicalId: (id: string) => string;
        getRestApiLogicalId: () => string;
        getApiGatewayName: () => string;
        normalizeNameToAlphaNumericOnly: (name: string) => string;
        getStackName: () => string;
    };
}
interface CFTemplate {
    Resources: Record<string, any>;
    Outputs: Record<string, any>;
}
interface Serverless {
    instanceId: string;
    cli: {
        log(message: string, prefix?: string, options?: Record<string, string>): null;
    };
    getProvider: (provider: string) => AwsProvider;
    service: {
        provider: {
            compiledCloudFormationTemplate: CFTemplate;
        };
        custom: {
            apiGatewayIntegrations?: ApiGatewayIntegration[];
        };
    };
}
export declare class ServerlessPlugin {
    private serverless;
    private options;
    private hooks;
    private apiGatewayMethodLogicalIds;
    constructor(serverless: Serverless, options: Options);
    private addIntegration;
    private createOrUpdateApiGateway;
    createIntegrations(): void;
}
export {};
